@@ -254,7 +254,6 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 	{
 		WidgetParameters params;
 		FrameParameters  frame;
-		int current_page, num_pages;
 		
 		frame.shadow    = shadow_type;
 		frame.gap_side  = gap_side;
@@ -264,78 +263,25 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
-		/* Modified from Aurora Engine
-		*** 
-		We need to fix the clip problem on first tab and rounded corners
-		Last Active tab could be buggied if the tabs cover more space then the notebook width
-		***
-		*/
-		current_page = gtk_notebook_get_current_page ((GtkNotebook *) widget);
-		num_pages = gtk_notebook_get_n_pages ((GtkNotebook *) widget);
-
-		if (frame.gap_side == CL_GAP_TOP) {
-			if ((current_page == 0) && (num_pages - 1 == 0)) {
-				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT;
-			}
-			else if (current_page == 0) {
-				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT;
-			}
-			else if (current_page == num_pages - 1) {
-				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT;
-				/* params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT; */
-			}
-			else {
-				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT;
-				/* params.corners = CR_CORNER_ALL; */
-			}
-		}
-		else if (frame.gap_side == CL_GAP_BOTTOM) {
-			if ((current_page == 0) && (num_pages - 1 == 0)) {
-				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT;
-			}
-			else if (current_page == 0) {
-				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
-			}
-			else if (current_page == num_pages - 1) {
-				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT;
-				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT; */
-			}
-			else {
-				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
-				/* params.corners = CR_CORNER_ALL; */
-			}
-		}
-		else if (frame.gap_side == CL_GAP_LEFT) {
-			if ((current_page == 0) && (num_pages - 1 == 0)) {
-				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
-			}
-			else if (current_page == 0) {
-				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
-			}
-			else if (current_page == num_pages - 1) {
-				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_TOPRIGHT;
-				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT; */
-			}
-			else {
-				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
-				/* params.corners = CR_CORNER_ALL; */
-			}
-		}
-		else {
-			if ((current_page == 0) && (num_pages - 1 == 0)) {
-				params.corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
-			}
-			else if (current_page == 0) {
-				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
-			}
-			else if (current_page == num_pages - 1) {
-				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT;
-				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT; */
-			}
-			else {
-				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
-				/* params.corners = CR_CORNER_ALL; */
-			}
+		switch (gap_side) {
+			case GTK_POS_LEFT:
+				params.corners = CR_CORNER_ALL ^ CR_CORNER_TOPLEFT;
+			break;
+			case GTK_POS_RIGHT:
+				params.corners = CR_CORNER_ALL ^ CR_CORNER_TOPRIGHT;
+			break;
+			case GTK_POS_TOP:
+				if (ge_widget_is_ltr (widget))
+					params.corners = CR_CORNER_ALL ^ CR_CORNER_TOPLEFT;
+				else
+					params.corners = CR_CORNER_ALL ^ CR_CORNER_TOPRIGHT;
+			break;
+			case GTK_POS_BOTTOM:
+				if (ge_widget_is_ltr (widget))
+					params.corners = CR_CORNER_ALL ^ CR_CORNER_BOTTOMLEFT;
+				else
+					params.corners = CR_CORNER_ALL ^ CR_CORNER_BOTTOMRIGHT;
+			break;
 		}
 
 		/* Fill the background with bg[NORMAL] */
@@ -848,7 +794,11 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		scrollbar.has_color  = FALSE;
 		scrollbar.horizontal = TRUE;
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
-		
+
+		if (clearlooks_style->colorize_scrollbar || clearlooks_style->has_scrollbar_color) {
+			scrollbar.has_color = TRUE;
+		}
+
 		scrollbar.horizontal = DETAIL ("hscrollbar");
 		
 		stepper.stepper = clearlooks_scrollbar_get_stepper (widget, &this_rectangle);
@@ -1489,8 +1439,8 @@ clearlooks_style_draw_layout (GtkStyle * style,
 		etched.green = (int) (temp.g * 65535);
 		etched.blue = (int) (temp.b * 65535);
 
-		gdk_draw_layout_with_colors (window, style->text_gc[state_type], x + 1, y + 1, layout, &etched, NULL);
-		gdk_draw_layout (window, style->text_gc[state_type], x, y, layout);
+		gdk_draw_layout_with_colors (window, gc, x + 1, y + 1, layout, &etched, NULL);
+		gdk_draw_layout (window, gc, x, y, layout);
 	}
 	else
 		gdk_draw_layout (window, gc, x, y, layout);
