@@ -1,3 +1,4 @@
+#include <math.h>
 #include "general-support.h"
 #include "cairo-support.h"
 
@@ -24,17 +25,17 @@ ge_hsb_from_color (const CairoColor *color,
 	if (red > green)
 	{
 		max = MAX(red, blue);
-		min = MIN(green, blue);      
+		min = MIN(green, blue);
 	}
 	else
 	{
 		max = MAX(green, blue);
-		min = MIN(red, blue);      
+		min = MIN(red, blue);
 	}
   
 	*brightness = (max + min) / 2;
  	
-	if (max == min)
+	if (fabs(max - min) < 0.0001)
 	{
 		*hue = 0;
 		*saturation = 0;
@@ -128,9 +129,9 @@ ge_gdk_color_to_cairo (const GdkColor *c, CairoColor *cc)
 
 	g_return_if_fail (c && cc);
 
-	r = c->red / 65536.0;
-	g = c->green / 65536.0;
-	b = c->blue / 65536.0;
+	r = c->red / 65535.0;
+	g = c->green / 65535.0;
+	b = c->blue / 65535.0;
 
 	cc->r = r;
 	cc->g = g;
@@ -145,9 +146,9 @@ ge_cairo_color_to_gtk (const CairoColor *cc, GdkColor *c)
 
 	g_return_if_fail (c && cc);
 
-	r = cc->r * 65536.0;
-	g = cc->g * 65536.0;
-	b = cc->b * 65536.0;
+	r = cc->r * 65535.0;
+	g = cc->g * 65535.0;
+	b = cc->b * 65535.0;
 
 	c->red = r;
 	c->green = g;
@@ -263,6 +264,17 @@ ge_cairo_set_color (cairo_t *cr, const CairoColor *color)
 	cairo_set_source_rgba (cr, color->r, color->g, color->b, color->a);	
 }
 
+void
+ge_cairo_set_gdk_color_with_alpha (cairo_t *cr, const GdkColor *color, gdouble alpha)
+{
+	g_return_if_fail (cr && color);
+
+	cairo_set_source_rgba (cr, color->red / 65535.0,
+	                           color->green / 65535.0,
+	                           color->blue / 65535.0,
+	                           alpha);
+}
+
 void 
 ge_cairo_pattern_add_color_stop_color (cairo_pattern_t *pattern, 
 						gfloat offset, 
